==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/catalan/main.php <==
<?php /* Catalan Translation by Marcelo Yuji Himoro <http://yuji.ws> */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'BULLETIN_MB_LOADED' ) ) {


// Appended by Xoops Language Checker -GIJOE- in 2007-05-08 12:57:30
define('_MD_TOPIC_IMAGE','Category image');
define('_MD_TOPIC_DISABLE','Do not display category icon');
define('_MD_TOPIC_LEFT','Display category icon on left side');
define('_MD_TOPIC_RIGHT','Display category icon on right side');
define('_MD_PUBINHOME','Publish on the index page');
define('_MD_PUBLISHED','Posted date');
define('_MD_EXPIRED','Expired');
define('_MD_SETDATETIME','Set the publication time');
define('_MD_SETDATETIME_DESC','* If you do not check it, published time will be current time.');
define('_MD_SETEXPDATETIME','Set expiration time');
define('_MD_SETEXPDATETIME_DESC','* If you do not check it, expired setting will become invalid.');
define('_MD_APPROVE','Approve this story');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Database updated successfully!');
define('_MD_POSTEDBY','Poster');
define('_MD_RELATION','Related articles');
define('_MD_ADD_RELATION','Add related articles');
define('_MD_CHECKED_AS_RELATION','Add as related articles');
define('_MD_DISP_BLOCK','Display on block');
define('_MD_RUSUREDEL','Are you sure you want to delete this news and all its comments?');
define('_MD_EMPTYNODELETE','Unable to delete.');
define('_MD_RSS','RSS');
define('_MD_ARCHIVES','Archive');

define( 'BULLETIN_MB_LOADED' , 1 ) ;

//%%%%%%		File Name index.php 		%%%%%
define("_MD_PRINTER","Pgina d'impressi");
define("_MD_SENDSTORY","Enviar aquesta noticia a un amic");
define("_MD_READMORE","Seguir llegint...");
define("_MD_COMMENTS","0 comentaris");
define("_MD_ONECOMMENT","1 comentari");
define("_MD_BYTESMORE","%s bytes restants");
define("_MD_NUMCOMMENTS","%s comentaris");

//%%%%%%		File Name submit.php		%%%%%
define("_MD_SUBMITNEWS","Enviar notcies");
define("_MD_TITLE","Assumpte");
define("_MD_TOPIC","Categoria");
define("_MD_THESCOOP","Text");
define("_MD_NOTIFYPUBLISH","Avisar-me quan s'aprovi aquesta notcia");
define("_MD_POST","Publicar");
define("_MD_GO","Enviar");
define("_MD_THANKS","S'ha rebut el teu enviament. Espera fins que l'equip d'aquesta web ho aprovi i ho publiqui definitivament."); //submission of news article
// Added 2.0.11jp
define("_MD_THANKS_AUTOAPPROVE", "Grcies pel teu enviament.");

define("_MD_NOTIFYSBJCT","NOTCIES a la meva pgina web"); // Notification mail subject
define("_MD_NOTIFYMSG","S'ha enviat una nova notcia."); // Notification mail message

//%%%%%%		File Name archive.php		%%%%%
define("_MD_NEWSARCHIVES","Arxiu de notcies");
define("_MD_ARTICLES","Notcies");
define("_MD_VIEWS","visualitzacions");
define("_MD_DATE","Data d'enviament");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","Pgina d'impressi");
define("_MD_THEREAREINTOTAL","Hi ha en total %s notcies.");

// %s is your site name
define("_MD_INTARTICLE","He trobat una notcia interessant a %s");
define("_MD_INTARTFOUND","A sota tens una notcia molt interessant que he trobat a %s:");

define("_MD_TOPICC","Categoria:");
define("_MD_URL","Adrea:");
define("_MD_NOSTORY","La notcia seleccionada no existeix.");

//%%%%%%	File Name print.php 	%%%%%

define("_MD_URLFORSTORY","L'adrea per a aquesta notcia:");

// %s represents your site name
define("_MD_THISCOMESFROM","Pots llegir ms notcies a %s.");

// Added language definitions for news expiry date
define("_AM_EXPARTS","Notcies expirades");
define("_AM_EXPIRED","Expirat");
define("_AM_CHANGEEXPDATETIME","Canviar la data de validesa");
define("_AM_SETEXPDATETIME","Fixar la data de validesa");
define("_AM_NOWSETEXPTIME","Data de validesa actual: %s");

// Added by suin
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","No hi ha cap arxiu.");
define("_MD_THANKS_BUT_ERROR", "Grcies pel teu enviament. No obstant, a causa d'un <span style=\"color:red\">error</span>, no s'ha publicat la teva notcia. Perdona les molsties, i contacta amb un administrador.");
define("_MD_USE_HTML","Activar HTML");
define("_MD_USE_SMILEY","Activar emoticones");
define("_MD_USE_BR","Activar salt de lnia automtic");
define("_MD_USE_XCODE","Activar Codi XOOPS");
define("_MD_JANUARY", "Gener");
define("_MD_FEBRUARY", "Febrer");
define("_MD_MARCH", "Mar");
define("_MD_APRIL", "Abril");
define("_MD_MAY", "Maig");
define("_MD_JUNE", "Juny");
define("_MD_JULY", "Juliol");
define("_MD_AUGUST", "Agost");
define("_MD_SEPTEMBER", "Setembre");
define("_MD_OCTOBER", "Octubre");
define("_MD_NOVEMBER", "Novembre");
define("_MD_DECEMBER", "Desembre");
define("_MD_NO_TOPICS","No hi ha cap categoria.");

}
?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/catalan/main.php <==
<?php /* Catalan Translation by Marcelo Yuji Himoro <http://yuji.ws> */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'BULLETIN_MB_LOADED' ) ) {



// Appended by Xoops Language Checker -GIJOE- in 2009-08-26 16:24:54
define('_MD_INPUTHELPER','Input Helper ON/OFF');
define('_MD_FCKXOOPS_ONOFF','FCK Editor ON/OFF (Note: Each of editors don&#039;t share the text)');
define('_MD_ERROR_REQUIRED','{0} is a required field.');

// Appended by Xoops Language Checker -GIJOE- in 2007-05-08 12:57:30
define('_MD_TOPIC_IMAGE','Category image');
define('_MD_TOPIC_DISABLE','Do not display category icon');
define('_MD_TOPIC_LEFT','Display category icon on left side');
define('_MD_TOPIC_RIGHT','Display category icon on right side');
define('_MD_PUBINHOME','Publish on the index page');
define('_MD_PUBLISHED','Posted date');
define('_MD_EXPIRED','Expired');
define('_MD_SETDATETIME','Set the publication time');
define('_MD_SETDATETIME_DESC','* If you do not check it, published time will be current time.');
define('_MD_SETEXPDATETIME','Set expiration time');
define('_MD_SETEXPDATETIME_DESC','* If you do not check it, expired setting will become invalid.');
define('_MD_APPROVE','Approve this story');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Database updated successfully!');
define('_MD_POSTEDBY','Poster');
define('_MD_RELATION','Related articles');
define('_MD_ADD_RELATION','Add related articles');
define('_MD_CHECKED_AS_RELATION','Add as related articles');
define('_MD_DISP_BLOCK','Display on block');
define('_MD_RUSUREDEL','Are you sure you want to delete this news and all its comments?');
define('_MD_EMPTYNODELETE','Unable to delete.');
define('_MD_RSS','RSS');
define('_MD_ARCHIVES','Archive');

define( 'BULLETIN_MB_LOADED' , 1 ) ;

//%%%%%%		File Name index.php 		%%%%%
define("_MD_PRINTER","Pgina d'impressi");
define("_MD_SENDSTORY","Enviar aquesta noticia a un amic");
define("_MD_READMORE","Seguir llegint...");
define("_MD_COMMENTS","0 comentaris");
define("_MD_ONECOMMENT","1 comentari");
define("_MD_BYTESMORE","%s bytes restants");
define("_MD_NUMCOMMENTS","%s comentaris");

//%%%%%%		File Name submit.php		%%%%%
define("_MD_SUBMITNEWS","Enviar notcies");
define("_MD_TITLE","Assumpte");
define("_MD_TOPIC","Categoria");
define("_MD_THESCOOP","Text");
define("_MD_NOTIFYPUBLISH","Avisar-me quan s'aprovi aquesta notcia");
define("_MD_POST","Publicar");
define("_MD_GO","Enviar");
define("_MD_THANKS","S'ha rebut el teu enviament. Espera fins que l'equip d'aquesta web ho aprovi i ho publiqui definitivament."); //submission of news article
// Added 2.0.11jp
define("_MD_THANKS_AUTOAPPROVE", "Grcies pel teu enviament.");

define("_MD_NOTIFYSBJCT","NOTCIES a la meva pgina web"); // Notification mail subject
define("_MD_NOTIFYMSG","S'ha enviat una nova notcia."); // Notification mail message

//%%%%%%		File Name archive.php		%%%%%
define("_MD_NEWSARCHIVES","Arxiu de notcies");
define("_MD_ARTICLES","Notcies");
define("_MD_VIEWS","visualitzacions");
define("_MD_DATE","Data d'enviament");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","Pgina d'impressi");
define("_MD_THEREAREINTOTAL","Hi ha en total %s notcies.");

// %s is your site name
define("_MD_INTARTICLE","He trobat una notcia interessant a %s");
define("_MD_INTARTFOUND","A sota tens una notcia molt interessant que he trobat a %s:");

define("_MD_TOPICC","Categoria:");
define("_MD_URL","Adrea:");
define("_MD_NOSTORY","La notcia seleccionada no existeix.");

//%%%%%%	File Name print.php 	%%%%%

define("_MD_URLFORSTORY","L'adrea per a aquesta notcia:");

// %s represents your site name
define("_MD_THISCOMESFROM","Pots llegir ms notcies a %s.");

// Added language definitions for news expiry date
define("_AM_EXPARTS","Notcies expirades");
define("_AM_EXPIRED","Expirat");
define("_AM_CHANGEEXPDATETIME","Canviar la data de validesa");
define("_AM_SETEXPDATETIME","Fixar la data de validesa");
define("_AM_NOWSETEXPTIME","Data de validesa actual: %s");

// Added by suin
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","No hi ha cap arxiu.");
define("_MD_THANKS_BUT_ERROR", "Grcies pel teu enviament. No obstant, a causa d'un <span style=\"color:red\">error</span>, no s'ha publicat la teva notcia. Perdona les molsties, i contacta amb un administrador.");
define("_MD_USE_HTML","Activar HTML");
define("_MD_USE_SMILEY","Activar emoticones");
define("_MD_USE_BR","Activar salt de lnia automtic");
define("_MD_USE_XCODE","Activar Codi XOOPS");
define("_MD_JANUARY", "Gener");
define("_MD_FEBRUARY", "Febrer");
define("_MD_MARCH", "Mar");
define("_MD_APRIL", "Abril");
define("_MD_MAY", "Maig");
define("_MD_JUNE", "Juny");
define("_MD_JULY", "Juliol");
define("_MD_AUGUST", "Agost");
define("_MD_SEPTEMBER", "Setembre");
define("_MD_OCTOBER", "Octubre");
define("_MD_NOVEMBER", "Novembre");
define("_MD_DECEMBER", "Desembre");
define("_MD_NO_TOPICS","No hi ha cap categoria.");

}
?>
